| Safe Haskell | None |
|---|
Game.LambdaHack.Frontend.Chosen
Contents
Description
Re-export the operations of the chosen raw frontend (determined at compile time with cabal flags).
- data FrontendSession
- startup :: String -> (FrontendSession -> IO ()) -> IO ()
- frontendName :: String
- promptGetAnyKey :: FrontendSession -> SingleFrame -> IO KM
- display :: FrontendSession -> Bool -> Maybe SingleFrame -> IO ()
Re-exported raw frontend
data FrontendSession Source
Session data maintained by the frontend.
startup :: String -> (FrontendSession -> IO ()) -> IO ()Source
Starts GTK. The other threads have to be spawned
after gtk is initialized, because they call postGUIAsync,
and need sview and stags. Because of Windows, GTK needs to be
on a bound thread, so we can't avoid the communication overhead
of bound threads, so there's no point spawning a separate thread for GTK.
The name of the frontend.
promptGetAnyKey :: FrontendSession -> SingleFrame -> IO KMSource
Display a prompt, wait for any key. Starts in Push or None mode, stop in None mode.
display :: FrontendSession -> Bool -> Maybe SingleFrame -> IO ()Source
Add a frame to be drawn.